@@ -412,7 +412,9 @@ def do_init(
     project.write_pyproject()
 
 
-def do_use(project: Project, python: str, first: bool = False) -> None:
+def do_use(
+    project: Project, python: Optional[str] = "", first: Optional[bool] = False
+) -> None:
     """Use the specified python version and save in project config.
     The python can be a version string or interpreter path.
     """
@@ -426,12 +428,11 @@ def do_use(project: Project, python: str, first: bool = False) -> None:
         dict.fromkeys(filter(version_matcher, project.find_interpreters(python)))
     )
     if not found_interpreters:
-        raise NoPythonVersion(
-            f"Python interpreter {python} is not found on the system."
-        )
+        raise NoPythonVersion("Python interpreter is not found on the system.")
     if first or len(found_interpreters) == 1:
         selected_python = found_interpreters[0]
     else:
+        project.core.ui.echo("Please enter the Python interpreter to use")
         for i, py_version in enumerate(found_interpreters):
             python_version = str(py_version.version)
             is_64bit = py_version.get_architecture() == "64bit"
