@@ -27,10 +27,7 @@ class Command(BaseCommand):
             project.core.ui.echo(
                 "{}".format(termui.cyan("Creating a pyproject.toml for PDM..."))
             )
-        python = click.prompt(
-            "Please enter the Python interpreter to use", default="", show_default=False
-        )
-        actions.do_use(project, python)
+        actions.do_use(project)
         is_library = click.confirm(
             "Is the project a library that will be upload to PyPI?",
         )
