@@ -12,6 +12,9 @@ class Command(BaseCommand):
         parser.add_argument(
             "--graph", action="store_true", help="Display a graph of dependencies"
         )
+        parser.add_argument(
+            "-r", "--reverse", action="store_true", help="Reverse the dependency graph"
+        )
 
     def handle(self, project: Project, options: argparse.Namespace) -> None:
-        actions.do_list(project, options.graph)
+        actions.do_list(project, options.graph, options.reverse)
