@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import functools
+import os
 import warnings
 from argparse import Namespace
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Sequence
@@ -15,7 +16,7 @@ from pdm.models import pip_shims
 from pdm.models.markers import Marker
 from pdm.models.readers import SetupReader
 from pdm.models.requirements import Requirement, filter_requirements_with_extras
-from pdm.utils import cached_property, path_replace
+from pdm.utils import cached_property, get_rev_from_url, path_replace
 
 if TYPE_CHECKING:
     from distlib.metadata import Metadata
@@ -138,6 +139,12 @@ class Candidate:
             raise AttributeError("Non-VCS candidate doesn't have revision attribute")
         if self.req.revision:
             return self.req.revision
+        if self.ireq.source_dir and not os.path.exists(self.ireq.source_dir):
+            # It happens because the cached wheel is hit and the source code isn't
+            # pulled to local. In this case the link url must contain the full commit
+            # hash which can be taken as the revision safely.
+            # See more info at https://github.com/pdm-project/pdm/issues/349
+            return get_rev_from_url(self.ireq.original_link.url)
         return vcs.get_backend(self.req.vcs).get_revision(self.ireq.source_dir)
 
     def get_metadata(
