@@ -18,6 +18,8 @@ def get_pypackages_path(maxdepth=5):
             path = os.path.dirname(path)
         return None
 
+    if "PEP582_PACKAGES" in os.environ:
+        return os.path.join(os.getenv("PEP582_PACKAGES"), "lib")
     find_paths = [os.getcwd()]
     version = bare_version = ".".join(map(str, sys.version_info[:2]))
     if os.name == "nt" and sys.maxsize <= 2 ** 32:
